# Moccasin Project

🐍 Welcome to your Moccasin project!

## Quickstart

```bash
mox init
mox run deploy
```

_For documentation, please run `mox --help` or visit [the Moccasin documentation](https://cyfrin.github.io/moccasin)_
